@@ -403,16 +403,35 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
 def plot_stat(morph, gal, imag, imagm, median_sky_g, area, t, zp, psfg, psf_g,
               sc_ima, arc_kpc, size_image_phy, show_plot='yes'):
 
+    if os.path.exists('properties.dat'):
+        data = ascii.read('properties.dat')
+    else:
+        direcbase = os.path.dirname(os.path.realpath(__file__))
+        datat = ascii.read(direcbase + '/properties.dat')
+        print (Fore.RED + '\n*It was create the properties.dat to print the out parameters')
 
-    data = ascii.read('properties.dat')
+        unitst = [str, np.float64, np.float64, np.float64, np.float64, np.float64,
+                 np.float64, np.float64, np.float64, np.float64, np.float64,
+                 np.float64, np.float64, np.float64, np.float64, np.float64,
+                 np.float64, np.float64, np.float64, np.float64, np.float64,
+                 np.float64, np.float64, np.float64, np.float64, np.float64,
+                 np.float64, np.float64, np.float64, np.float64, np.float64,
+                 np.float64, np.float64, np.float64, np.float64, np.float64,
+                 np.float64, np.float64, np.float64, np.float64, np.float64,
+                 np.float64, np.float64, np.float64, np.float64, np.float64,
+                 np.float64, np.float64, np.float64, np.float64]
+        data= Table( names=datat.colnames, dtype=unitst)
+        data.add_row()
+        data['GAL'] = data['GAL'].astype('U'+str(len(gal)))
+        data['GAL'][0] = gal
 
     if any(data['GAL'] == gal):
-        print ('Row was updated')
+        print (Fore.BLACK +'\nRow was updated')
         print (data['GAL'][data['GAL']==gal])
         ind=np.where(data['GAL']==gal)[0][0]
 
     else:
-        print ('Row was created for {}'.format(gal))
+        print (Fore.BLACK +'\nRow was created for {}'.format(gal))
         data.add_row()
         ind = -1
         if len(gal) > len(data['GAL'][0]):
@@ -428,7 +447,6 @@ def plot_stat(morph, gal, imag, imagm, median_sky_g, area, t, zp, psfg, psf_g,
     print ('flag_sersic =', morph.flag_sersic)
     print ('')
 
-
     data['r20'][ind] = morph.r20
     data['r80'][ind] = morph.r80
     data['Gini'][ind] = morph.gini
@@ -439,6 +457,22 @@ def plot_stat(morph, gal, imag, imagm, median_sky_g, area, t, zp, psfg, psf_g,
     data['C'][ind] = morph.concentration
     data['A'][ind] = morph.asymmetry
     data['S'][ind] = morph.smoothness
+
+    data['r50'][ind] = morph.r50
+
+    data['flux_c'][ind] = morph.flux_circ
+    data['flux_e'][ind] = morph.flux_ellip
+    data['rpetro_c'][ind] = morph.rpetro_circ
+    data['rpetro_e'][ind] = morph.rpetro_ellip
+    data['rhalf_c'][ind] =  morph.rhalf_circ
+    data['rhalf_e'][ind] = morph.rhalf_ellip
+
+    data['M'][ind] = morph.multimode
+    data['I'][ind] = morph.intensity
+    data['D'][ind] = morph.deviation
+    data['Ao'][ind] = morph.outer_asymmetry
+    data['As'][ind] = morph.shape_asymmetry
+
     data['Ser_A'][ind] = morph.sersic_amplitude
     data['Ser_R'][ind] = morph.sersic_rhalf
     data['Ser_n'][ind] = morph.sersic_n
@@ -603,6 +637,13 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
             print (Fore.RED +"the photometric analysis is not possible!")
             return
 
+    if not os.path.exists('fits_images'):
+        os.system('mkdir fits_images')
+        print (Fore.RED+ '\nThe folder fits_images was created')
+
+    if not os.path.exists('images'):
+        os.system('mkdir images')
+        print (Fore.RED+ '\nThe folder images was created')
 
     print ('')
     radsimbad = field_size_phy
@@ -1191,6 +1232,10 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
         print("")
         for i, (comp_ind, comp) in enumerate(zip(user_order, user_text)):
 
+            if len(data) == 0:
+                data.add_row()
+
+
             if any(data['GAL'] == comp):
                 print (Fore.RED +f"Row for {comp} was updated")
                 #print (data['GAL'][data['GAL']==comp])
@@ -1439,7 +1484,7 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
 
 def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
                         areagal=2, band='r', sky_box=[100, 100], deblend='off',
-                        psf=1, run_auto='yes', show_plot='yes'):
+                        psf=1, run_auto='no', show_plot='yes'):
 
     idg =np.where(tab_gal['gal']==gal)[0][0]
     D = tab_gal['vel'][idg]/H
@@ -1458,6 +1503,13 @@ def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
     print (Fore.BLUE +'Minimum detection area {:.1f} kcp^2 = {:.0f} pix'.format(areagal,
            area_min))
 
+    if not os.path.exists('fits_images'):
+        os.system('mkdir fits_images')
+        print (Fore.RED+ '\nThe folder fits_images was created')
+
+    if not os.path.exists('images'):
+        os.system('mkdir images')
+        print (Fore.RED+ '\nThe folder images was created')
 
     print(Fore.BLACK +'\n\nLoading/Downloading the images and tables')
     print('---------------------------------------------')
